@@ -4,7 +4,7 @@ qr code displayer widget
 
 the popup widget :class:`QrDisplayerPopup` provided by this ae namespace portion is displaying QR codes.
 
-the :class:`QrDisplayerPopup` is inherited from :class:`ae.kivy_app.FlowPopup` and is embedding the Kivy Garden
+the :class:`QrDisplayerPopup` is inherited from :class:`ae.kivy.widgets.FlowPopup` and is embedding the Kivy Garden
 :mod:`kivy_garden.qrcode` module.
 
 qr displayer popup usage
@@ -29,7 +29,7 @@ translation texts provided in the resources of this ae namespace portion.
 
 .. note::
     if your app is providing i18n translations then the `qr_content` string has to be translated (e.g. by using
-    :meth:`~ae.kivy_app.get_txt` or :meth:`~ae.i18n.get_text`) before it gets passed to the popup kwargs.
+    :meth:`~ae.kivy.i18n.get_txt` or :meth:`~ae.i18n.get_text`) before it gets passed to the popup kwargs.
 
 to support additional languages simply add the translations texts to your app's translation texts resources or submit a
 PR to add them to this ae namespace portion. alternatively you could put different wording by specifying also the
@@ -46,10 +46,10 @@ from kivy.properties import StringProperty          # type: ignore # pylint: dis
 from kivy_garden.qrcode import QRCodeWidget         # type: ignore # noqa: F401
 
 from ae.i18n import register_package_translations   # type: ignore
-from ae.kivy_app import FlowPopup                   # type: ignore
+from ae.kivy.widgets import FlowPopup               # type: ignore
 
 
-__version__ = '0.3.7'
+__version__ = '0.3.8'
 
 
 register_package_translations()
